TChannel.py
===========

|build-status| |coverage| |docs|

TChannel.py is a Python implementation of `TChannel`_.

`Documentation`_ is available on Read the docs.

.. _TChannel: https://github.com/uber/tchannel
.. _Documentation: http://tchannel.readthedocs.org/en/latest/

.. |build-status| image:: https://travis-ci.org/uber/tchannel.py.svg?branch=master
    :alt: build status
    :scale: 100%
    :target: https://travis-ci.org/uber/tchannel.py

.. |coverage| image:: https://coveralls.io/repos/uber/tchannel.py/badge.svg?branch=master
    :alt: coverage
    :scale: 100%
    :target: https://coveralls.io/r/uber/tchannel.py?branch=master

.. |docs| image:: https://readthedocs.org/projects/tchannel/badge/?version=latest
    :alt: documentation
    :scale: 100%
    :target: http://tchannel.readthedocs.org/en/latest/
